searchNodes=[{"ref":"Chunky.html","title":"Chunky","type":"module","doc":"Extended chunking and enumeration manipulations. Functions Chunky.permutations/1 - Generate all combinations of a set of values, with no duplication Chunky.filter_with_predicates/2 - Filter an enumeration to only those entries that meet all the provided predicate functions Chunky.chunk_runs/1 - Chunk an enumerable by runs of duplicate values Chunky.chunk_to_length/2 - Chunk an enumerable into specific length chunks TODO: Chunky.filter_with_predicates/2 TODO: Chunky.take_sequences/1 TODO: Chunky.take_chunks/2 TODO: top level API doc for install instructions and pointers into module docs"},{"ref":"Chunky.html#permutations/1","title":"Chunky.permutations/1","type":"function","doc":"Generate all of the permutations, without duplicates, from a set of values. The type of the set of values can be: a list of any type, like [1, 2, 3] or [:a, :b, %{}] a string or binary, like &quot;abcd&quot; a tuple, like {1, :b, &quot;asdf&quot;} a range, like 1..4 or 3..-1 This is not lazy generated, so a permutation of a large set may take awhile. Keep in mind that the total number of permutations for a set of N values is N!. When a set is permuted, the resulting list will contain values in the shape of the original; a permuted list will contains lists, permuted tuples will contain tuples, permuted strings will contain strings. The only exception is ranges, which will result in lists. So, for instance, a permuted string will result in a list of strings. Chunky should handle Unicode just fine: iex&gt; Chunky.permutations(&quot;😀★⍵&quot;) [&quot;😀★⍵&quot;, &quot;😀⍵★&quot;, &quot;★😀⍵&quot;, &quot;★⍵😀&quot;, &quot;⍵😀★&quot;, &quot;⍵★😀&quot;] Supported Permutations The Chunky.permutations/1 function can work with sets of any size (memory and time permitting). Examples that follow usually use sets with a length of 3 for ease of documentation. The following types of sets are supported as permutations: List A list with just about any kind of value can be permuted, and the result will be a list of lists: iex&gt; Chunky.permutations([1, 2, 3]) [[1, 2, 3], [1, 3, 2], [2, 1, 3], [2, 3, 1], [3, 1, 2], [3, 2, 1]] iex&gt; Chunky.permutations([:a, &quot;b&quot;, 3]) [ [:a, &quot;b&quot;, 3], [:a, 3, &quot;b&quot;], [&quot;b&quot;, :a, 3], [&quot;b&quot;, 3, :a], [3, :a, &quot;b&quot;], [3, &quot;b&quot;, :a] ] Collections, types, and other values can be permuted as well: iex&gt; Chunky.permutations([~D(2019-12-05), %{a: &quot;foo&quot;}, {:tup, :le}]) [ [~D[2019-12-05], %{a: &quot;foo&quot;}, {:tup, :le}], [~D[2019-12-05], {:tup, :le}, %{a: &quot;foo&quot;}], [%{a: &quot;foo&quot;}, ~D[2019-12-05], {:tup, :le}], [%{a: &quot;foo&quot;}, {:tup, :le}, ~D[2019-12-05]], [{:tup, :le}, ~D[2019-12-05], %{a: &quot;foo&quot;}], [{:tup, :le}, %{a: &quot;foo&quot;}, ~D[2019-12-05]] ] String/Binary Permuted strings are returned as a list of strings. Chunky works with full UTF-8, including multi-code point glyphs like emojis and variable emojis. iex&gt; Chunky.permutations(&quot;abc&quot;) [&quot;abc&quot;, &quot;acb&quot;, &quot;bac&quot;, &quot;bca&quot;, &quot;cab&quot;, &quot;cba&quot;] iex&gt; Chunky.permutations(&quot;😀🤷🏽‍♀️⭐️&quot;) [ &quot;😀🤷🏽‍♀️⭐️&quot;, &quot;😀⭐️🤷🏽‍♀️&quot;, &quot;🤷🏽‍♀️😀⭐️&quot;, &quot;🤷🏽‍♀️⭐️😀&quot;, &quot;⭐️😀🤷🏽‍♀️&quot;, &quot;⭐️🤷🏽‍♀️😀&quot; ] Tuple When tuples are permuted, the resulting list will also contain tuples. As part of the permutation the original tuple is converted to a list, before the final values of the permutation are re-assembled into tuples. Like working with lists, tuples can contain any values: iex&gt; Chunky.permutations({:a, :b, :c}) [ {:a, :b, :c}, {:a, :c, :b}, {:b, :a, :c}, {:b, :c, :a}, {:c, :a, :b}, {:c, :b, :a} ] iex&gt; Chunky.permutations({:task, ~D(2019-12-09), %{value: &quot;timer&quot;}}) [ {:task, ~D[2019-12-09], %{value: &quot;timer&quot;}}, {:task, %{value: &quot;timer&quot;}, ~D[2019-12-09]}, {~D[2019-12-09], :task, %{value: &quot;timer&quot;}}, {~D[2019-12-09], %{value: &quot;timer&quot;}, :task}, {%{value: &quot;timer&quot;}, :task, ~D[2019-12-09]}, {%{value: &quot;timer&quot;}, ~D[2019-12-09], :task} ] Ranges Ranges can be used to create permutations over ordered lists of numbers. Before permutation the provided range is converted into a list. Increasing or decreasing ranges are supported. iex&gt; Chunky.permutations(3..5) [[3, 4, 5], [3, 5, 4], [4, 3, 5], [4, 5, 3], [5, 3, 4], [5, 4, 3]] iex&gt; Chunky.permutations(-10..-12) [ [-10, -11, -12], [-10, -12, -11], [-11, -10, -12], [-11, -12, -10], [-12, -10, -11], [-12, -11, -10] ] Examples iex&gt; Chunky.permutations([1, 2, 3]) [[1, 2, 3], [1, 3, 2], [2, 1, 3], [2, 3, 1], [3, 1, 2], [3, 2, 1]] iex&gt; Chunky.permutations(&quot;abc&quot;) [&quot;abc&quot;, &quot;acb&quot;, &quot;bac&quot;, &quot;bca&quot;, &quot;cab&quot;, &quot;cba&quot;] iex&gt; Chunky.permutations({:a, :b, :c}) [ {:a, :b, :c}, {:a, :c, :b}, {:b, :a, :c}, {:b, :c, :a}, {:c, :a, :b}, {:c, :b, :a} ] iex&gt; Chunky.permutations(1..-1) [ [1, 0, -1], [1, -1, 0], [0, 1, -1], [0, -1, 1], [-1, 1, 0], [-1, 0, 1]]"},{"ref":"readme.html","title":"Chunky","type":"extras","doc":"Chunky Chunking and Enumeration manipulations in Elixir. iex&gt; Chunky.permutations(&quot;😀🤷🏽‍♀️⭐️&quot;) [ &quot;😀🤷🏽‍♀️⭐️&quot;, &quot;😀⭐️🤷🏽‍♀️&quot;, &quot;🤷🏽‍♀️😀⭐️&quot;, &quot;🤷🏽‍♀️⭐️😀&quot;, &quot;⭐️😀🤷🏽‍♀️&quot;, &quot;⭐️🤷🏽‍♀️😀&quot; ] iex&gt; Chunky.permutations(1..4) [ [1, 2, 3, 4], [1, 2, 4, 3], [1, 3, 2, 4], [1, 3, 4, 2], [1, 4, 2, 3], [1, 4, 3, 2], ... ]"},{"ref":"readme.html#installation","title":"Chunky - Installation","type":"extras","doc":"Install by adding chunky to your list of dependencies in mix.exs: def deps do [ {:chunky, &quot;~&gt; 0.1.1&quot;} ] end Chunky documentation can be found on Hexdocs at https://hexdocs.pm/chunky."},{"ref":"readme.html#documentation","title":"Chunky - Documentation","type":"extras","doc":"See Chunky on Hexdocs."}]